@@ -14,6 +14,7 @@ from atk_common.enums.image_encoding_type_enum import ImageEncodingType
 from atk_common.enums.image_part_category_enum import ImagePartCategory
 from atk_common.enums.image_part_type_enum import ImagePartType
 from atk_common.enums.image_shelf_type_enum import ImageShelfType
+from atk_common.enums.log_level_enum import LogLevel
 from atk_common.enums.metering_direction_enum import MeteringDirection
 from atk_common.enums.multimotor_status_type_enum import MultiMotorStatusType
 from atk_common.enums.piezo_vehicle_type_enum import PiezoVehicleType
@@ -43,6 +44,7 @@ __all__ = [
     'ImagePartCategory',
     'ImagePartType',
     'ImageShelfType',
+    'LogLevel',
     'MeteringDirection',
     'MultiMotorStatusType',
     'PiezoVehicleType',
