@@ -2,4 +2,4 @@ from enum import Enum
  
 class EncryptionType(Enum):
     NONE = 1
-    X25519AESGCM = 2
+    X25519_AES_GCM = 2
