@@ -1,5 +1,5 @@
 from enum import Enum
  
 class MeteringDirection(Enum):
-    WITHMETERING = 1
-    AGAINSTMETERING = 2
+    WITH_METERING = 1
+    AGAINST_METERING = 2
