@@ -1,7 +1,7 @@
 import unittest
 import sys, os
 sys.path.insert(0, os.path.abspath(os.path.join(os.path.dirname(__file__), '..', 'src')))
-from atk_common import *
+from atk_common.utils import *
 from atk_common.enums import *
 
 class TestDockerUtils(unittest.TestCase):
